package CPAN::Daily;

use strict;
use vars qw($VERSION @EXPORT @ISA);

$VERSION = '0.01';

require Exporter;
@ISA = qw(Exporter);
@EXPORT = qw(read_update);

=head1 NAME

CPAN::Daily - Read the daily CPAN update email


=head1 SYNOPSIS

  use CPAN::Daily;

  my @todays_modules = read_update(@email);


=head1 DESCRIPTION

Reads the cpan-daily@cpan.org daily email about what CPAN modules were
uploaded.


=over 4

=item B<read_update>

  my @todays_modules = read_update(@email);

Reads the given email and returns a list of modules uploaded.

  $todays_modules[0] = {
                        authorid => 'KANE',
                        package  => 'Acme-POE-Knee-1.10.zip'
                       };

=cut

use Mail::Internet;


sub read_update {
    my(@email) = @_;

    my $body = Mail::Internet->new(@email)->body;

    until( $body->[0] =~ /^\[\d+\.\]/ ) {
        shift @$body;
    }

    my @modules = ({});
    foreach my $line (@$body) {
        if( $line =~ /^\s*$/ ) {
            push @modules, {};
            next;
        }

        if( $line =~ /^CPAN id:\s+(\S+)/ ) {
            (my($id) = $1) =~ s|^.*/||;
            $modules[-1]{authorid} = $id;
        }
        elsif( $line =~ /^Package:\s+(\S+)/ ) {
            $modules[-1]{package} = $1;
        }
    }

    return @modules;
}

=back

=cut

1;
